size(200, 200)

bez = BezierPath()
bez.beginPath()
bez.addPoint((20, 20), "move")
bez.addPoint((20, 100), "line")
bez.addPoint((100, 100), "line")
bez.addPoint((100, 180), "line")
bez.addPoint((150, 180))
bez.addPoint((180, 150))
bez.addPoint((180, 100), "curve")
bez.addPoint((180, 50), "line")
bez.addPoint((180, 20))
bez.addPoint((150, 20), "qcurve")
bez.endPath()

fill(1, 0, 0)
stroke(0)
strokeWidth(10)
drawPath(bez)

fill(None)
stroke(1)
translate(40, 15)
scale(0.7)
lineCap("round")
lineJoin("round")

drawPath(bez)
